#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-refactor-plugin-2.3.0.0-HqxB9BZJRKR2yZ9XFDzide
key:                  hls-refactor-plugin-2.3.0.0-HqxB9BZJRKR2yZ9XFDzide
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  daa808d3fc4c376ddaaaa1f35d888fef
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.3.0.0-HqxB9BZJRKR2yZ9XFDzide
depends:
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX
    ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-Ag67m4VkTysHJaCSg4DehN
    ghcide-2.3.0.0-ADJYfTGFlXED5XUWhMGPcf
    hls-graph-2.3.0.0-5TnZntcxnjfFOE8vvh0bLs
    hls-plugin-api-2.3.0.0-Jg5s5m9Ajd96ODSU64WGQ6
    lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    lsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1 mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    regex-applicative-0.3.4-BFylRaA4NgGE57E8BzAJb3
    regex-tdfa-1.3.2.6-7s6a3kMa1YssqXiRAnHSe
    retrie-1.2.3-JkO7LnZl4WoJyBOG8JH567
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE text-2.0.2
    text-rope-0.3-EGYQdR2gSK4IsR7LLld6Sh time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

